@@ -37,5 +37,5 @@ class DatabaseConfig:
             password=self.password,
             host=self.host,
             port=self.port,
-            database=self.dbname or self.db_name,
+            database=self.dbname or self.db_name
         )
